@@ -53,6 +53,13 @@ const unsigned NAME##_NPARAMS = 3; \
 template<typename T1, typename T2, typename T3> const GiNaC::function NAME(const T1 & p1, const T2 & p2, const T3 & p3) { \
 	return GiNaC::function(NAME##_SERIAL::serial, GiNaC::ex(p1), GiNaC::ex(p2), GiNaC::ex(p3)); \
 }
+
+#define DECLARE_FUNCTION_6P(NAME) \
+class NAME##_SERIAL { public: static unsigned serial; }; \
+const unsigned NAME##_NPARAMS = 6; \
+template<typename T1, typename T2, typename T3, typename T4, typename T5, typename T6> const GiNaC::function NAME(const T1 & p1, const T2 & p2, const T3 & p3, const T4 & p4, const T5 & p5, const T6 & p6) { \
+	return GiNaC::function(NAME##_SERIAL::serial, GiNaC::ex(p1), GiNaC::ex(p2), GiNaC::ex(p3), GiNaC::ex(p4), GiNaC::ex(p5), GiNaC::ex(p6)); \
+}
 // end of generated lines
 
 #define REGISTER_FUNCTION(NAME,OPT) \
@@ -79,9 +86,11 @@ typedef void (* print_funcp)();
 typedef ex (* eval_funcp_1)(const ex &);
 typedef ex (* eval_funcp_2)(const ex &, const ex &);
 typedef ex (* eval_funcp_3)(const ex &, const ex &, const ex &);
+typedef ex (* eval_funcp_6)(const ex &, const ex &, const ex &, const ex &, const ex &, const ex &);
 typedef ex (* evalf_funcp_1)(const ex &, PyObject* parent);
 typedef ex (* evalf_funcp_2)(const ex &, const ex &, PyObject* parent);
 typedef ex (* evalf_funcp_3)(const ex &, const ex &, const ex &, PyObject* parent);
+typedef ex (* evalf_funcp_6)(const ex &, const ex &, const ex &, const ex &, const ex &, const ex &, PyObject* parent);
 
 typedef ex (* conjugate_funcp_1)(const ex &);
 typedef ex (* conjugate_funcp_2)(const ex &, const ex &);
@@ -97,6 +106,7 @@ typedef ex (* imag_part_funcp_3)(const ex &, const ex &, const ex &);
 typedef ex (* derivative_funcp_1)(const ex &, unsigned);
 typedef ex (* derivative_funcp_2)(const ex &, const ex &, unsigned);
 typedef ex (* derivative_funcp_3)(const ex &, const ex &, const ex &, unsigned);
+typedef ex (* derivative_funcp_6)(const ex &, const ex &, const ex &, const ex &, const ex &, const ex &, unsigned);
 typedef ex (* power_funcp_1)(const ex &, const ex &);
 typedef ex (* power_funcp_2)(const ex &, const ex &, const ex &);
 typedef ex (* power_funcp_3)(const ex &, const ex &, const ex &, const ex &);
@@ -143,10 +153,12 @@ public:
     function_options & eval_func(eval_funcp_1 e);
     function_options & eval_func(eval_funcp_2 e);
     function_options & eval_func(eval_funcp_3 e);
+    function_options & eval_func(eval_funcp_6 e);
 
     function_options & evalf_func(evalf_funcp_1 ef);
     function_options & evalf_func(evalf_funcp_2 ef);
     function_options & evalf_func(evalf_funcp_3 ef);
+    function_options & evalf_func(evalf_funcp_6 ef);
 
     function_options & conjugate_func(conjugate_funcp_1 d);
     function_options & conjugate_func(conjugate_funcp_2 d);
@@ -163,6 +175,7 @@ public:
     function_options & derivative_func(derivative_funcp_1 d);
     function_options & derivative_func(derivative_funcp_2 d);
     function_options & derivative_func(derivative_funcp_3 d);
+    function_options & derivative_func(derivative_funcp_6 d);
 
     function_options & power_func(power_funcp_1 d);
     function_options & power_func(power_funcp_2 d);
@@ -248,7 +261,7 @@ public:
 		subs_python_f           = 0x0100,
 	};
 
-protected:
+public:
 	bool has_derivative() const { return derivative_f != nullptr; }
 	bool has_power() const { return power_f != nullptr; }
 	void test_and_set_nparams(unsigned n);
@@ -326,10 +339,11 @@ class function : public exprseq
 	// other constructors
 public:
 	function(unsigned ser);
-	// the following lines have been generated for max. 14 parameters
+	// the following lines have been generated for some parameters
     function(unsigned ser, const ex & param1);
     function(unsigned ser, const ex & param1, const ex & param2);
     function(unsigned ser, const ex & param1, const ex & param2, const ex & param3);
+    function(unsigned ser, const ex & param1, const ex & param2, const ex & param3, const ex & param4, const ex & param5, const ex & param6);
 	// end of generated lines
 	function(unsigned ser, exprseq  es);
 	function(unsigned ser, const exvector & v, bool discardable = false);
@@ -337,27 +351,27 @@ public:
 
 	// functions overriding virtual functions from base classes
 public:
-	void print(const print_context & c, unsigned level = 0) const;
-	unsigned precedence() const {return 70;}
-	ex expand(unsigned options=0) const;
-	ex eval(int level=0) const;
-	ex evalf(int level=0, PyObject* parent=nullptr) const;
-	unsigned calchash() const;
-	ex series(const relational & r, int order, unsigned options = 0) const;
-        ex subs(const exmap & m, unsigned options = 0) const;
-	ex thiscontainer(const exvector & v) const;
-	ex thiscontainer(std::unique_ptr<exvector> vp) const;
-	ex conjugate() const;
-	ex real_part() const;
-	ex imag_part() const;
-	bool info(unsigned inf) const;
+	void print(const print_context & c, unsigned level = 0) const override;
+	unsigned precedence() const override {return 70;}
+	ex expand(unsigned options=0) const override;
+	ex eval(int level=0) const override;
+	ex evalf(int level=0, PyObject* parent=nullptr) const override;
+	long calchash() const override;
+	ex series(const relational & r, int order, unsigned options = 0) const override;
+        ex subs(const exmap & m, unsigned options = 0) const override;
+	ex thiscontainer(const exvector & v) const override;
+	ex thiscontainer(std::unique_ptr<exvector> vp) const override;
+	ex conjugate() const override;
+	ex real_part() const override;
+	ex imag_part() const override;
+	bool info(unsigned inf) const override;
 	//int compare(const basic &other) const;
 protected:
-	ex derivative(const symbol & s) const;
-	bool is_equal_same_type(const basic & other) const;
-	bool match_same_type(const basic & other) const;
-	unsigned return_type() const;
-	tinfo_t return_type_tinfo() const;
+	ex derivative(const symbol & s) const override;
+	bool is_equal_same_type(const basic & other) const override;
+	bool match_same_type(const basic & other) const override;
+	unsigned return_type() const override;
+	tinfo_t return_type_tinfo() const override;
 	
 	// new virtual functions which can be overridden by derived classes
 	// none
