@@ -62,7 +62,7 @@ public:
 	ex real_part() const override;
 	ex imag_part() const override;
 	ex series(const relational & s, int order, unsigned options = 0) const override;
-	ex normal(exmap & repl, exmap & rev_lookup, int level = 0) const override;
+	ex normal(exmap & repl, exmap & rev_lookup, int level = 0, unsigned options = 0) const override;
 	numeric integer_content() const override;
 	ex smod(const numeric &xi) const override;
 	numeric max_coefficient() const override;
@@ -101,6 +101,7 @@ public:
 	const epvector & get_sorted_seq() const override;
 	//int compare_symbol(const symbol &other) const;
 	//int compare_pow(const power &other) const;
+        ex without_known_factor(const ex& f) const;
 protected:
 	void print_overall_coeff(const ex coeff_ex, const print_context & c,
 			const char *mul_sym, bool latex=false) const;
